# ModuleConfiguration

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**beta** | **bool** |  | [optional] 
**brand** | **str** |  | [optional] 
**can_get_samples** | **bool** |  | [optional] 
**category** | **str** |  | [optional] 
**cmdline** | **str** |  | [optional] 
**commit_message** | **str** |  | [optional] 
**configuration** | [**list[ConfigField]**](ConfigField.md) |  | [optional] 
**deprecated** | **bool** |  | [optional] 
**description** | **str** |  | [optional] 
**detailed_description** | **str** |  | [optional] 
**display** | **str** |  | [optional] 
**executable** | **str** |  | [optional] 
**hidden** | **bool** |  | [optional] 
**hide_engines** | **bool** |  | [optional] 
**icon** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**image** | **str** |  | [optional] 
**integration_script** | [**IntegrationScript**](IntegrationScript.md) |  | [optional] 
**is_password_protected** | **bool** |  | [optional] 
**locked** | **bool** |  | [optional] 
**modified** | **datetime** |  | [optional] 
**name** | **str** |  | [optional] 
**path** | **str** |  | [optional] 
**prev_name** | **str** |  | [optional] 
**propagation_labels** | **list[str]** |  | [optional] 
**readonly** | **bool** |  | [optional] 
**script_not_visible** | **bool** |  | [optional] 
**should_commit** | **bool** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**source_module_id** | **str** |  | [optional] 
**system** | **bool** |  | [optional] 
**vc_should_ignore** | **bool** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


